@@ -6,7 +6,6 @@
 
 from tornado.options import options, define
 
-
 from lesscode.web.business_exception import BusinessException
 from lesscode.web.status_code import StatusCode
 
@@ -67,6 +66,54 @@ class InitConnectionPool:
                     if pool:
                         options.database[conn_info.name] = (pool, conn_info.dialect)
 
+    @staticmethod
+    def sync_create_pool():
+        """
+                获取配置的链接信息，生成对应的连接池
+                :return:
+                """
+        if options.conn_info:
+            for conn_info in options.conn_info:
+                if conn_info.enable:
+                    if options.database.keys().__contains__(conn_info.name):
+                        # 相同key的连接池已经存在，抛出异常
+                        raise BusinessException(StatusCode.RESOURCE_EXIST(f"{conn_info.name}连接池"))
+                    pool = None
+                    # 依据数据库类型进行链接池创建
+                    if conn_info.dialect == "postgresql":
+                        clazz = InitConnectionPool.getClass("lesscode.db.postgresql.postgresql_pool",
+                                                            fromlist="PostgresqlPool")
+                        # 执行用例
+                        pool = clazz(conn_info).sync_create_pool()
+                    elif conn_info.dialect == "mysql":
+                        # 获取包中用例的函数引用
+                        clazz = InitConnectionPool.getClass("lesscode.db.mysql.mysql_pool", fromlist="MysqlPool")
+                        # 执行用例
+                        pool = clazz(conn_info).sync_create_pool()
+                    elif conn_info.dialect == "mongodb":
+                        # 获取包中用例的函数引用
+                        clazz = InitConnectionPool.getClass("lesscode.db.mongodb.mongodb_pool", fromlist="MongodbPool")
+                        # 执行用例
+                        pool = clazz(conn_info).sync_create_pool()
+                    elif conn_info.dialect == "elasticsearch":
+                        # 获取包中用例的函数引用
+                        clazz = InitConnectionPool.getClass("lesscode.db.elasticsearch.elasticsearch_pool",
+                                                            fromlist="ElasticsearchPool")
+                        # 执行用例
+                        pool = clazz(conn_info).sync_create_pool()
+                    elif conn_info.dialect == "esapi":
+                        # 获取包中用例的函数引用
+                        clazz = InitConnectionPool.getClass("lesscode.db.es.es_pool", fromlist="EsPool")
+                        # 执行用例
+                        pool = clazz(conn_info).create_pool()
+                    elif conn_info.dialect == "redis":
+                        # 获取包中用例的函数引用
+                        clazz = InitConnectionPool.getClass("lesscode.db.redis.redis_pool", fromlist="RedisPool")
+                        # 执行用例
+                        pool = clazz(conn_info).sync_create_pool()
+                    if pool:
+                        options.database[conn_info.name] = (pool, conn_info.dialect)
+
     @staticmethod
     def getClass(name, fromlist):
         return getattr(__import__(name, fromlist=fromlist), fromlist)
