@@ -2,6 +2,7 @@ import json
 import aiohttp
 import tornado.options
 import requests
+import py_eureka_client.eureka_client as eureka_client
 
 
 async def post(path, data=None,
@@ -50,3 +51,27 @@ def sync_post(path, data=None,
     else:
         res = res.text
     return res
+
+
+def eureka_request(path="", return_type="json", method="GET", data=None, app_name="DATA_SERVICE", pack=True, **kwargs):
+    if not kwargs.get("headers"):
+        kwargs.update({"headers": {
+            "Content-Type": "application/json"
+        }})
+    res = eureka_client.do_service(app_name=app_name, service=path, return_type=return_type, method=method, data=data,
+                                   **kwargs)
+    if return_type == "json" and not pack:
+        res = res.get("data")
+    return res
+
+
+def eureka_get(path="", return_type="json", data=None, app_name="DATA_SERVICE", pack=True, **kwargs):
+    res = eureka_request(path=path, return_type=return_type, method="GET", data=data, app_name=app_name, pack=pack,
+                         **kwargs)
+    return res
+
+
+def eureka_post(path="", return_type="json", data=None, app_name="DATA_SERVICE", pack=True, **kwargs):
+    res = eureka_request(path=path, return_type=return_type, method="POST", data=json.dumps(data), app_name=app_name,
+                         pack=pack, **kwargs)
+    return res
