@@ -34,6 +34,8 @@ define("eureka_server", default="", type=str, help="eureka server地址")
 define("eureka_instance_name", default="", type=str, help="eureka实例名称，大写")
 define("eureka_instance_ip", default="", type=str, help="eureka实例ip或者域名")
 define("eureka_instance_port", default=8901, type=int, help="eureka实例ip或者域名")
+define("rms_register_enable", default=False, type=bool, help="是否启动资源注册")
+define("rms_register_server", default="http://127.0.0.1:8918", type=str, help="启动资源注册")
 # 日志初始化配置，配置文件中可修改设置
 options.logging = "DEBUG"
 options.log_rotate_mode = "time"
@@ -47,6 +49,8 @@ options.eureka_server = ""
 options.eureka_instance_name = ""
 options.eureka_instance_ip = ""
 options.eureka_instance_port = 8901
+options.rms_register_enable = False
+options.rms_register_server = "http://127.0.0.1:8918"
 
 
 class LogFormatter(TornadoLogFormatter):
@@ -143,7 +147,8 @@ class WebServer:
         finally:
             # 关掉连接池
             for item in options.database.items():
-                tornado.ioloop.IOLoop.current().run_sync(item[1][0].close)
+                if hasattr(item[1][0], "close"):
+                    tornado.ioloop.IOLoop.current().run_sync(item[1][0].close)
         return self
 
     def autoRegisterHandler(self, path, pkg_name):
